PhysicsDiagnostics

Trait PhysicsDiagnostics 

pub trait PhysicsDiagnostics: Default + Resource<Mutability = Mutable> {
    // Provided methods
    fn timer_paths(&self) -> Vec<(&'static DiagnosticPath, Duration)> { ... }
    fn counter_paths(&self) -> Vec<(&'static DiagnosticPath, u32)> { ... }
    fn reset(physics_diagnostics: ResMut<'_, Self>) { ... }
}
A trait for resources storing timers and counters for physics diagnostics.

Provided Methods

fn timer_paths(&self) -> Vec<(&'static DiagnosticPath, Duration)>

Maps diagnostic paths to their respective duration fields.

fn counter_paths(&self) -> Vec<(&'static DiagnosticPath, u32)>

Maps diagnostic paths to their respective counter fields.

fn reset(physics_diagnostics: ResMut<'_, Self>)

A system that resets the diagnostics to their default values.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors